==> blesta-5.10.2.zip: blesta/plugins/system_status/language/nl_nl/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.nl_nl
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.index.sql_mariadb_version_requirements'] = 'Zie minimumvereisten';
$lang['AdminMain.index.sql_mariadb_version_serious'] = 'De MariaDB-versie voldoet niet aan de minimale systeemvereisten.';
$lang['AdminMain.index.sql_mysql_version_requirements'] = 'Zie minimumvereisten';
$lang['AdminMain.index.sql_mysql_version_serious'] = 'De MySQL-versie voldoet niet aan de minimale systeemvereisten.';
$lang['AdminMain.index.php_version_requirements'] = 'Zie minimumvereisten';
$lang['AdminMain.index.php_version_serious'] = 'De PHP-versie voldoet niet aan de minimale systeemvereisten.';
$lang['AdminMain.index.db_version_upgrade'] = 'Upgraden?';
$lang['AdminMain.index.db_version_serious'] = 'De databaseversie komt niet overeen met de systeemversie.';
$lang['AdminMain.index.updates_buy'] = 'Ondersteuning en updates toevoegen?';
$lang['AdminMain.index.updates_serious'] = 'Uw ondersteuning en updates zijn verlopen op %1$s.';
$lang['AdminMain.index.updates_minor'] = 'Uw ondersteuning en updates zijn goed tot %1$s.';
$lang['AdminMain.index.updates_forever'] = 'Jullie ondersteuning en updates zijn voor altijd goed.';
$lang['AdminMain.index.error_reporting'] = 'errorReporting of System.debug zijn ingeschakeld in /config/blesta.php. Tenzij u actief een probleem aan het oplossen bent, moeten deze worden uitgeschakeld. errorReporting moet 0 zijn, System.debug moet false zijn.';
$lang['AdminMain.index.log_files_owner_minor'] = 'Sommige logbestanden zijn niet eigendom van dezelfde gebruiker als de webserver.  Dit wordt meestal veroorzaakt doordat de cron draait als een andere gebruiker dan de webserver.';
$lang['AdminMain.index.system_dir_writable_setting'] = 'Update?';
$lang['AdminMain.index.system_dir_writable_minor'] = 'Een systeemdirectory is niet beschrijfbaar.';
$lang['AdminMain.index.docroot_setting'] = 'Update?';
$lang['AdminMain.index.docroot_minor'] = 'Het gedetecteerde document root pad komt niet overeen met de Root Web Directory instelling.';
$lang['AdminMain.index.backup_minor'] = 'Er zijn de afgelopen 7 dagen geen back-ups uitgevoerd.';
$lang['AdminMain.index.invoices_configure'] = 'Configureren?';
$lang['AdminMain.index.invoices_minor'] = 'Facturen zijn de afgelopen 24 uur niet automatisch aangemaakt via cron.';
$lang['AdminMain.index.trial_buy'] = 'Nu kopen?';
$lang['AdminMain.index.trial_minor'] = 'Uw proeflicentie verloopt op %1$s.';
$lang['AdminMain.index.cron_task_stalled_automation'] = 'Geautomatiseerde taken weergeven';
$lang['AdminMain.index.cron_task_stalled_minor'] = 'Er zijn een of meer cron-taken die al meer dan %1$s minuten aan het uitvoeren zijn.';
$lang['AdminMain.index.cron_configure'] = 'Configureren?';
$lang['AdminMain.index.cron_minor'] = 'Cron heeft de afgelopen 24 uur niet gedraaid.';
$lang['AdminMain.index.cron_serious'] = 'Cron heeft nog nooit gedraaid.';
$lang['AdminMain.index.boxtitle_feed'] = 'Systeemstatus';
$lang['AdminMain.index.health_poor'] = 'Er zijn ernstige problemen die het vermogen van het systeem om normaal te werken beïnvloeden. Deze moeten zo snel mogelijk worden opgelost.';
$lang['AdminMain.index.health_fair'] = 'Er zijn enkele problemen die het vermogen van het systeem om normaal te werken beïnvloeden.';
$lang['AdminMain.index.health_good'] = 'Over het algemeen is het systeem in goede gezondheid, maar er zijn een paar punten die je aandacht nodig kunnen hebben.';
$lang['AdminMain.index.health_excellent'] = 'Het systeem is in goede gezondheid en lijkt normaal te werken.';

==> blesta-5.11.4.zip: blesta/plugins/system_status/language/nl_nl/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.nl_nl
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.index.sql_mariadb_version_requirements'] = 'Zie minimumvereisten';
$lang['AdminMain.index.sql_mariadb_version_serious'] = 'De MariaDB-versie voldoet niet aan de minimale systeemvereisten.';
$lang['AdminMain.index.sql_mysql_version_requirements'] = 'Zie minimumvereisten';
$lang['AdminMain.index.sql_mysql_version_serious'] = 'De MySQL-versie voldoet niet aan de minimale systeemvereisten.';
$lang['AdminMain.index.php_version_requirements'] = 'Zie minimumvereisten';
$lang['AdminMain.index.php_version_serious'] = 'De PHP-versie voldoet niet aan de minimale systeemvereisten.';
$lang['AdminMain.index.db_version_upgrade'] = 'Upgraden?';
$lang['AdminMain.index.db_version_serious'] = 'De databaseversie komt niet overeen met de systeemversie.';
$lang['AdminMain.index.updates_buy'] = 'Ondersteuning en updates toevoegen?';
$lang['AdminMain.index.updates_serious'] = 'Uw ondersteuning en updates zijn verlopen op %1$s.';
$lang['AdminMain.index.updates_minor'] = 'Uw ondersteuning en updates zijn goed tot %1$s.';
$lang['AdminMain.index.updates_forever'] = 'Jullie ondersteuning en updates zijn voor altijd goed.';
$lang['AdminMain.index.error_reporting'] = 'errorReporting of System.debug zijn ingeschakeld in /config/blesta.php. Tenzij u actief een probleem aan het oplossen bent, moeten deze worden uitgeschakeld. errorReporting moet 0 zijn, System.debug moet false zijn.';
$lang['AdminMain.index.log_files_owner_minor'] = 'Sommige logbestanden zijn niet eigendom van dezelfde gebruiker als de webserver.  Dit wordt meestal veroorzaakt doordat de cron draait als een andere gebruiker dan de webserver.';
$lang['AdminMain.index.system_dir_writable_setting'] = 'Update?';
$lang['AdminMain.index.system_dir_writable_minor'] = 'Een systeemdirectory is niet beschrijfbaar.';
$lang['AdminMain.index.docroot_setting'] = 'Update?';
$lang['AdminMain.index.docroot_minor'] = 'Het gedetecteerde document root pad komt niet overeen met de Root Web Directory instelling.';
$lang['AdminMain.index.backup_minor'] = 'Er zijn de afgelopen 7 dagen geen back-ups uitgevoerd.';
$lang['AdminMain.index.invoices_configure'] = 'Configureren?';
$lang['AdminMain.index.invoices_minor'] = 'Facturen zijn de afgelopen 24 uur niet automatisch aangemaakt via cron.';
$lang['AdminMain.index.trial_buy'] = 'Nu kopen?';
$lang['AdminMain.index.trial_minor'] = 'Uw proeflicentie verloopt op %1$s.';
$lang['AdminMain.index.cron_task_stalled_automation'] = 'Geautomatiseerde taken weergeven';
$lang['AdminMain.index.cron_task_stalled_minor'] = 'Er zijn een of meer cron-taken die al meer dan %1$s minuten aan het uitvoeren zijn.';
$lang['AdminMain.index.cron_configure'] = 'Configureren?';
$lang['AdminMain.index.cron_minor'] = 'Cron heeft de afgelopen 24 uur niet gedraaid.';
$lang['AdminMain.index.cron_serious'] = 'Cron heeft nog nooit gedraaid.';
$lang['AdminMain.index.boxtitle_feed'] = 'Systeemstatus';
$lang['AdminMain.index.health_poor'] = 'Er zijn ernstige problemen die het vermogen van het systeem om normaal te werken beïnvloeden. Deze moeten zo snel mogelijk worden opgelost.';
$lang['AdminMain.index.health_fair'] = 'Er zijn enkele problemen die het vermogen van het systeem om normaal te werken beïnvloeden.';
$lang['AdminMain.index.health_good'] = 'Over het algemeen is het systeem in goede gezondheid, maar er zijn een paar punten die je aandacht nodig kunnen hebben.';
$lang['AdminMain.index.health_excellent'] = 'Het systeem is in goede gezondheid en lijkt normaal te werken.';
$lang['AdminMain.index.upload_dir_configure'] = 'Configureren?';
$lang['AdminMain.index.upload_dir'] = 'Het pad van de uploadmap in uw instellingen bevindt zich in de hoofdmap van het web.  Het moet boven de root web directory worden geplaatst om er zeker van te zijn dat er nooit een probleem is met de publieke toegankelijkheid.';
